#########################################
TransactionPartnerUserTransactionTypeEnum
#########################################


.. automodule:: litegram.enums.transaction_partner_user_transaction_type_enum
    :members:
    :member-order: bysource
    :undoc-members: True
